@@ -2,12 +2,12 @@ import datetime
 import json
 import platform
 import re
-import six
 import ssl
 import time
 import types
 
-from six.moves.urllib.parse import urlencode, quote_plus, urlparse
+import six
+from six.moves.urllib.parse import quote_plus, urlencode, urlparse
 
 from .version import VERSION, VERSION_INFO
 
@@ -701,15 +701,15 @@ class Insurance(AllResource, CreateResource):
     pass
 
 
-class CustomsItem(AllResource, CreateResource):
+class CustomsItem(CreateResource):
     pass
 
 
-class CustomsInfo(AllResource, CreateResource):
+class CustomsInfo(CreateResource):
     pass
 
 
-class Parcel(AllResource, CreateResource):
+class Parcel(CreateResource):
     pass
 
 
@@ -728,6 +728,13 @@ class Shipment(AllResource, CreateResource):
         self.refresh_from(response, api_key)
         return self
 
+    def get_smartrates(self):
+        requestor = Requestor(self._api_key)
+        url = "%s/%s" % (self.instance_url(), "smartrate")
+
+        response, api_key = requestor.request('get', url)
+        return response
+
     def buy(self, **params):
         requestor = Requestor(self._api_key)
         url = "%s/%s" % (self.instance_url(), "buy")
@@ -868,7 +875,7 @@ class Tracker(AllResource, CreateResource):
         return convert_to_easypost_object(response["trackers"], api_key), response["has_more"]
 
 
-class Pickup(AllResource, CreateResource):
+class Pickup(CreateResource):
     def buy(self, **params):
         requestor = Requestor(self._api_key)
         url = "%s/%s" % (self.instance_url(), "buy")
@@ -884,7 +891,7 @@ class Pickup(AllResource, CreateResource):
         return self
 
 
-class Order(AllResource, CreateResource):
+class Order(CreateResource):
     def get_rates(self):
         requestor = Requestor(self._api_key)
         url = "%s/%s" % (self.instance_url(), "rates")
@@ -904,7 +911,7 @@ class PickupRate(Resource):
     pass
 
 
-class Event(Resource):
+class Event(AllResource, Resource):
     @classmethod
     def receive(self, values):
         return convert_to_easypost_object(json.loads(values), api_key)
@@ -980,6 +987,7 @@ class Report(AllResource, CreateResource):
         response, api_key = requestor.request('get', url, params)
         return convert_to_easypost_object(response, api_key)
 
+
 class Blob(AllResource, CreateResource):
     @classmethod
     def retrieve(cls, easypost_id, api_key=None, **params):
@@ -993,6 +1001,7 @@ class Blob(AllResource, CreateResource):
         response, api_key = requestor.request('get', url)
         return response["signed_url"]
 
+
 class Webhook(AllResource, CreateResource, DeleteResource):
     def update(self, **params):
         requestor = Requestor(self._api_key)
